# rag_chroma

Fetch embedding results from a chroma db. The node will get the query passed in
the input message, and return a number of results retrieved from the database.

## Node type: proc

## Node class name: RagChroma

## Node name: rag_chroma

